==> biostime-openapi-sdk-1.2.1.RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/member/MemberCallFinishReqBean.java <==
package global.hh.openapi.sdk.api.bean.member;

        import java.util.List;

/**
 * @description: 对外暴露api接口
 * @author: 777771
 * @date: 2019-37-26 21:37:55
 */
public class MemberCallFinishReqBean {
    /**
     * 时间戳，GMT格式日期
     */
    private String dateTime;

    /**
     * 通话任务是否成功
     */
    private String jobFinished;

    /**
     * 通话实例
     */
    private MemberCallFinishSceneInstanceBean sceneInstance;

    /**
     * 签名
     */
    private String sign;

    /**
     * 任务结果分析
     */
    private List<MemberCallFinishTaskResultItem> taskResult;

    public MemberCallFinishReqBean(){
    }

    public MemberCallFinishReqBean(String dateTime,String jobFinished,MemberCallFinishSceneInstanceBean sceneInstance,String sign,List<MemberCallFinishTaskResultItem> taskResult){
        this.dateTime=dateTime;
        this.jobFinished=jobFinished;
        this.sceneInstance=sceneInstance;
        this.sign=sign;
        this.taskResult=taskResult;
    }

    private String getDateTime() {
        return dateTime;
    }

    private void setDateTime(String dateTime) {
        this.dateTime = dateTime;
    }
    private String getJobFinished() {
        return jobFinished;
    }

    private void setJobFinished(String jobFinished) {
        this.jobFinished = jobFinished;
    }
    private MemberCallFinishSceneInstanceBean getSceneInstance() {
        return sceneInstance;
    }

    private void setSceneInstance(MemberCallFinishSceneInstanceBean sceneInstance) {
        this.sceneInstance = sceneInstance;
    }
    private String getSign() {
        return sign;
    }

    private void setSign(String sign) {
        this.sign = sign;
    }
    private List<MemberCallFinishTaskResultItem> getTaskResult() {
        return taskResult;
    }

    private void setTaskResult(List<MemberCallFinishTaskResultItem> taskResult) {
        this.taskResult = taskResult;
    }
}

==> biostime-openapi-sdk-1.5.9.2-RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/member/MemberCallFinishReqBean.java <==
package global.hh.openapi.sdk.api.bean.member;

        import java.util.List;

/**
 * @description: 对外暴露api接口
 * @author: 13351
 * @date: 2019-46-29 12:46:19
 */
public class MemberCallFinishReqBean {
    /**
     * 时间戳，GMT格式日期
     */
    private String dateTime;

    /**
     * 通话任务是否成功
     */
    private String jobFinished;

    /**
     * 通话实例
     */
    private MemberCallFinishSceneInstanceBean sceneInstance;

    /**
     * 签名
     */
    private String sign;

    /**
     * 任务结果分析
     */
    private List<MemberCallFinishTaskResultItem> taskResult;

    public MemberCallFinishReqBean(){
    }

    public MemberCallFinishReqBean(String dateTime,String jobFinished,MemberCallFinishSceneInstanceBean sceneInstance,String sign,List<MemberCallFinishTaskResultItem> taskResult){
        this.dateTime=dateTime;
        this.jobFinished=jobFinished;
        this.sceneInstance=sceneInstance;
        this.sign=sign;
        this.taskResult=taskResult;
    }

    public String getDateTime() {
        return dateTime;
    }

    public void setDateTime(String dateTime) {
        this.dateTime = dateTime;
    }
    public String getJobFinished() {
        return jobFinished;
    }

    public void setJobFinished(String jobFinished) {
        this.jobFinished = jobFinished;
    }
    public MemberCallFinishSceneInstanceBean getSceneInstance() {
        return sceneInstance;
    }

    public void setSceneInstance(MemberCallFinishSceneInstanceBean sceneInstance) {
        this.sceneInstance = sceneInstance;
    }
    public String getSign() {
        return sign;
    }

    public void setSign(String sign) {
        this.sign = sign;
    }
    public List<MemberCallFinishTaskResultItem> getTaskResult() {
        return taskResult;
    }

    public void setTaskResult(List<MemberCallFinishTaskResultItem> taskResult) {
        this.taskResult = taskResult;
    }
}
